# nimble-miner-api

## Release

Run the following command to create dist folder
```bash
python setup.py sdist
```

Then use the following command to publish to pypi
```bash
twine upload dist/nimble-miner-api-{version}.tar.gz
```
